@@ -1,4 +1,4 @@
-#Author: Michael Sieger <michael.sieger@student.hswt.de>
+#Author: Michael Sieger <sieger-michael@web.de>
 #Project responsible: Dr. Georg Ohmayer <georg.ohmayer@hswt.de>
 #Copyrights: Hochschule Weihenstephan-Triesdorf
 
@@ -24,8 +24,6 @@ LinkageMap <- function(xSammon, dist, lineTypes=c("solid","dotted", "dashed"), l
 			ylab = "", main = "")
 	{	 
 
-	library(aplpack)
-
 	# checking input
 	xdim = dim(xSammon)
 	llen = length(labels)
